ANTHROPIC_MODELS = {
  "claude-3.5-Sonnet": "claude-3-5-sonnet-20240620",
  "claude-3-Sonnet": "claude-3-sonnet-20240229",
  "claude-3-Opus": "claude-3-opus-20240229",
  "claude-3-Haiku": "claude-3-haiku-20240307",
}
