OPEN_AI_CHAT_MODELS = {
  "gpt-4o": "gpt-4o",
  "gpt-4o-2024-05-13": "gpt-4o-2024-05-13",
  "gpt-4-turbo": "gpt-4-turbo",
  "gpt-4-turbo-2024-04-09": "gpt-4-turbo-2024-04-09",
  "gpt-4-turbo-preview": "gpt-4-turbo-preview",
  "gpt-4-0125-preview": "gpt-4-0125-preview",
  "gpt-4-1106-preview": "gpt-4-1106-preview",
  "gpt-4": "gpt-4",
  "gpt-4-0613": "gpt-4-0613",
  "gpt-4-0314": "gpt-4-0314",
  "gpt-3.5-turbo-0125": "gpt-3.5-turbo-0125",
  "gpt-3.5-turbo": "gpt-3.5-turbo",
  "gpt-3.5-turbo-1106": "gpt-3.5-turbo-1106",
  "gpt-3.5-turbo-instruct": "gpt-3.5-turbo-instruct"
}

OPEN_AI_IMAGE_MODELS = {
  "dall-e-3": "dall-e-3",
  "dall-e-2": "dall-e-2",
}

OPEN_AI_VOICE_MODELS = {
  "tts-1": "tts-1",
  "tts-1-hd": "tts-1-hd",
}

OPEN_AI_EMBEDDING_MODELS = {
  "text-embedding-3-large": "text-embedding-3-large",
  "text-embedding-3-small": "text-embedding-3-small",
  "text-embedding-ada-002": "text-embedding-ada-002",
}
